import { Menu, Transition } from "@headlessui/react";
import { FC, Fragment, PropsWithChildren } from "react";

type NavMenuProps = {
  icon: any,
  width: string
}

const NavMenu: FC<PropsWithChildren<NavMenuProps>> = ({
  children,
  icon,
  width
}) => {
  return (
    <Menu as="div" className="relative ml-3">
      <div>
        <Menu.Button className="ml-3 rounded-full bg-c-pink p-1 text-white hover:text-white focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink">
          {icon}
        </Menu.Button>
      </div>
      <Transition
        as={Fragment}
        enter="transition ease-out duration-100"
        enterFrom="transform opacity-0 scale-95"
        enterTo="transform opacity-100 scale-100"
        leave="transition ease-in duration-75"
        leaveFrom="transform opacity-100 scale-100"
        leaveTo="transform opacity-0 scale-95"
      >
        <Menu.Items className={`absolute right-0 z-10 mt-2 origin-top-right rounded-md bg-white shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none ${width}`}>
          {/* <div className='w-full border-b'>
            <p className='block px-4 py-2 text-xs text-gray-400'>asdf</p>
          </div> */}
          <div className="p-2">
            {children}
          </div>
        </Menu.Items>
      </Transition>
    </Menu>
  )
}

export default NavMenu;