import { Post } from "@/types/post"
import { FC, PropsWithChildren } from "react"
import { EyeSlashIcon, HeartIcon, ChatBubbleLeftIcon } from '@heroicons/react/24/outline'
import LikeStack from "./LikeStack"
import Comment from "../comments/Comment"
import styles from '../../styles/AnswerCard.module.css'

type AnswerCardProps = {
  post: Post;
  commentLimit: number;
}

const AnswerCard: FC<PropsWithChildren<AnswerCardProps>> = ({
  post,
  commentLimit
}) => {

  return (
    <div className="flex-1 rounded-3xl bg-white text-lg shadow-lg overflow-hidden relative">
      <div className="p-4">
        <p className="text-sm text-gray-600">{`${post.User.name}'s answer`}</p>
        <div>
          This is my super duper answer. My name is Timmy C and I enjoy smooth jazz.
        </div>
        <div className="mt-2 flex ">
          <div className="flex-1">
            <button
              type="button"
              className="ml-auto mr-2 flex-shrink-0 rounded-full bg-white p-1 text-c-pink hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink"
            >
              <span className="sr-only">View notifications</span>
              <HeartIcon className="h-6 w-6" aria-hidden="true"/>
            </button>
            <button
              type="button"
              className="ml-auto mr-2 flex-shrink-0 rounded-full bg-white p-1 text-c-pink hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-c-pink"
            >
              <span className="sr-only">View notifications</span>
              <ChatBubbleLeftIcon className="h-6 w-6" aria-hidden="true"/>
            </button>
          </div>
          <LikeStack Users={[post.User, post.User, post.User, post.User, post.User, post.User]} />
        </div>
      </div>

    
    

    <div className="border-t bg-gray-50 p-2">
      <p className="text-xs text-gray-500 hover:text-c-pink">View all 3 comments</p>
      <Comment Comment={{Data: "asdfg", User: post.User}} />
    </div>

    {/* <div className={styles.hidden}>
      <div className="flex justify-center flex-col  items-center">
          <EyeSlashIcon className="h-10 w-10 text-c-pink"/>
          <p className="text-sm text-c-pink">This post is hidden</p>

          <button
            className="rounded-md bg-white px-3.5 py-2 mt-2 text-xs font-semibold text-c-pink shadow-sm hover:bg-c-pink hover:text-white focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-pink-400"
          >
            Post your daily
          </button>
      </div>
    </div> */}


  </div>
  )
}

export default AnswerCard